==> kubernetes-model-autoscaling-6.5.1-sources.jar: io/fabric8/kubernetes/api/model/autoscaling/v2beta2/ContainerResourceMetricStatusFluent.java <==
package io.fabric8.kubernetes.api.model.autoscaling.v2beta2;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public interface ContainerResourceMetricStatusFluent<A extends ContainerResourceMetricStatusFluent<A>> extends Fluent<A>{
  public String getContainer();
  public A withContainer(String container);
  public Boolean hasContainer();
  
  /**
   * This method has been deprecated, please use method buildCurrent instead.
   * @return The buildable object.
   */
  @Deprecated
  public MetricValueStatus getCurrent();
  public MetricValueStatus buildCurrent();
  public A withCurrent(MetricValueStatus current);
  public Boolean hasCurrent();
  public ContainerResourceMetricStatusFluent.CurrentNested<A> withNewCurrent();
  public ContainerResourceMetricStatusFluent.CurrentNested<A> withNewCurrentLike(MetricValueStatus item);
  public ContainerResourceMetricStatusFluent.CurrentNested<A> editCurrent();
  public ContainerResourceMetricStatusFluent.CurrentNested<A> editOrNewCurrent();
  public ContainerResourceMetricStatusFluent.CurrentNested<A> editOrNewCurrentLike(MetricValueStatus item);
  public String getName();
  public A withName(String name);
  public Boolean hasName();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface CurrentNested<N> extends Nested<N>,MetricValueStatusFluent<ContainerResourceMetricStatusFluent.CurrentNested<N>>{
    public N and();
    public N endCurrent();
    
  }
  
}

==> kubernetes-model-autoscaling-6.7.1-sources.jar: io/fabric8/kubernetes/api/model/autoscaling/v2beta2/ContainerResourceMetricStatusFluent.java <==
package io.fabric8.kubernetes.api.model.autoscaling.v2beta2;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface ContainerResourceMetricStatusFluent<A extends ContainerResourceMetricStatusFluent<A>> extends Fluent<A>{
  public String getContainer();
  public A withContainer(String container);
  public Boolean hasContainer();
  
  /**
   * This method has been deprecated, please use method buildCurrent instead.
   * @return The buildable object.
   */
  @Deprecated
  public MetricValueStatus getCurrent();
  public MetricValueStatus buildCurrent();
  public A withCurrent(MetricValueStatus current);
  public Boolean hasCurrent();
  public ContainerResourceMetricStatusFluent.CurrentNested<A> withNewCurrent();
  public ContainerResourceMetricStatusFluent.CurrentNested<A> withNewCurrentLike(MetricValueStatus item);
  public ContainerResourceMetricStatusFluent.CurrentNested<A> editCurrent();
  public ContainerResourceMetricStatusFluent.CurrentNested<A> editOrNewCurrent();
  public ContainerResourceMetricStatusFluent.CurrentNested<A> editOrNewCurrentLike(MetricValueStatus item);
  public String getName();
  public A withName(String name);
  public Boolean hasName();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface CurrentNested<N> extends Nested<N>,MetricValueStatusFluent<ContainerResourceMetricStatusFluent.CurrentNested<N>>{
    public N and();
    public N endCurrent();
    
  }
  
}
